@@ -1,7 +1,7 @@
 # COPYRIGHT (C) 2020-2022 Nicotine+ Contributors
 # COPYRIGHT (C) 2016-2017 Michael Labouebe <gfarmerfr@free.fr>
-# COPYRIGHT (C) 2008-2009 Quinox <quinox@users.sf.net>
-# COPYRIGHT (C) 2006-2009 Daelstorm <daelstorm@gmail.com>
+# COPYRIGHT (C) 2008-2009 quinox <quinox@users.sf.net>
+# COPYRIGHT (C) 2006-2009 daelstorm <daelstorm@gmail.com>
 # COPYRIGHT (C) 2003-2004 Hyriand <hyriand@thegraveyard.org>
 #
 # GNU GENERAL PUBLIC LICENSE
@@ -23,6 +23,7 @@
 import sys
 
 from gi.repository import Gdk
+from gi.repository import GLib
 from gi.repository import Gtk
 
 from pynicotine.config import config
@@ -340,7 +341,7 @@ class IconNotebook:
         self.set_tab_reorderable(page, True)
         self.set_show_tabs(True)
 
-    def append_page(self, page, text, close_callback=None, full_text=None, user=None):
+    def append_page(self, page, text, focus_callback=None, close_callback=None, full_text=None, user=None):
 
         if full_text is None:
             full_text = text
@@ -351,15 +352,20 @@ class IconNotebook:
         if GTK_API_VERSION >= 4:
             label_tab.gesture_click = Gtk.GestureClick()
             label_tab.add_controller(label_tab.gesture_click)  # pylint: disable=no-member
+
+            page.get_first_child().hide()
         else:
             label_tab.gesture_click = Gtk.GestureMultiPress(widget=label_tab)
 
+            page.get_children()[0].hide()
+
         label_tab.gesture_click.set_button(Gdk.BUTTON_MIDDLE)
         label_tab.gesture_click.connect("pressed", label_tab.close_callback, page)
 
         # menu for all tabs
         label_tab_menu = TabLabel(text)
 
+        page.focus_callback = focus_callback
         self.append_page_label(page, label_tab, label_tab_menu)
 
         if user is not None:
@@ -558,9 +564,15 @@ class IconNotebook:
             current_page.get_children()[0].hide()
             new_page.get_children()[0].show()
 
+        if self.parent_page is None:
+            return
+
+        # Focus the default widget on the page
+        if self.frame.current_page_id == self.parent_page.id:
+            GLib.idle_add(new_page.focus_callback, priority=GLib.PRIORITY_HIGH_IDLE)
+
         # Dismiss tab highlight
-        if self.parent_page is not None:
-            self.remove_tab_hilite(new_page)
+        self.remove_tab_hilite(new_page)
 
     def on_reorder_page(self, _notebook, page, page_num):
         if self.reorder_page_callback is not None:
