@@ -1,6 +1,6 @@
 # COPYRIGHT (C) 2020-2022 Nicotine+ Contributors
-# COPYRIGHT (C) 2009-2011 Quinox <quinox@users.sf.net>
-# COPYRIGHT (C) 2007-2009 Daelstorm <daelstorm@gmail.com>
+# COPYRIGHT (C) 2009-2011 quinox <quinox@users.sf.net>
+# COPYRIGHT (C) 2007-2009 daelstorm <daelstorm@gmail.com>
 # COPYRIGHT (C) 2003-2004 Hyriand <hyriand@thegraveyard.org>
 # COPYRIGHT (C) 2001-2003 Alexander Kanavin
 #
@@ -31,6 +31,7 @@ server messages and p2p messages (between clients). """
 
 
 UINT_LIMIT = 4294967295
+UINT64_LIMIT = 18446744073709551615
 
 INT_UNPACK = struct.Struct("<i").unpack
 UINT_UNPACK = struct.Struct("<I").unpack
@@ -109,6 +110,20 @@ class InternalMessage:
     msgtype = MessageType.INTERNAL
 
 
+class CloseConnection(InternalMessage):
+
+    def __init__(self, sock=None):
+        self.sock = sock
+
+
+class CloseConnectionIP(InternalMessage):
+    """ Sent by the main thread to the networking thread in order to close any connections
+    using a certain IP address. """
+
+    def __init__(self, addr=None):
+        self.addr = addr
+
+
 class ServerConnect(InternalMessage):
     """ NicotineCore sends this to make networking thread establish a server connection. """
 
@@ -127,7 +142,7 @@ class ServerTimeout(InternalMessage):
     pass
 
 
-class InitPeerConn(InternalMessage):
+class InitPeerConnection(InternalMessage):
 
     __slots__ = ("addr", "init")
 
@@ -136,36 +151,22 @@ class InitPeerConn(InternalMessage):
         self.init = init
 
 
-class ConnClose(InternalMessage):
-
-    def __init__(self, sock=None):
-        self.sock = sock
-
-
-class ConnCloseIP(InternalMessage):
-    """ Sent by the main thread to the networking thread in order to close any connections
-    using a certain IP address. """
-
-    def __init__(self, addr=None):
-        self.addr = addr
-
-
 class SendNetworkMessage(InternalMessage):
 
-    def __init__(self, user=None, message=None, addr=None):
+    def __init__(self, user=None, message=None):
         self.user = user
         self.message = message
-        self.addr = addr
 
 
 class ShowConnectionErrorMessage(InternalMessage):
 
-    def __init__(self, user=None, msgs=None):
+    def __init__(self, user=None, msgs=None, offline=False):
         self.user = user
         self.msgs = msgs
+        self.offline = offline
 
 
-class MessageProgress(InternalMessage):
+class PeerMessageProgress(InternalMessage):
     """ Used to indicate progress of long transfers. """
 
     __slots__ = ("user", "msg_type", "position", "total")
@@ -177,6 +178,14 @@ class MessageProgress(InternalMessage):
         self.total = total
 
 
+class PeerConnectionClosed(InternalMessage):
+
+    __slots__ = ("user",)
+
+    def __init__(self, user=None):
+        self.user = user
+
+
 class TransferTimeout(InternalMessage):
 
     __slots__ = ("transfer",)
@@ -199,20 +208,22 @@ class DownloadFile(InternalMessage):
     """ Sent by networking thread to indicate file transfer progress.
     Sent by UI to pass the file object to write. """
 
-    __slots__ = ("sock", "file", "leftbytes")
+    __slots__ = ("init", "token", "file", "leftbytes")
 
-    def __init__(self, sock=None, file=None, leftbytes=None):
-        self.sock = sock
+    def __init__(self, init=None, token=None, file=None, leftbytes=None):
+        self.init = init
+        self.token = token
         self.file = file
         self.leftbytes = leftbytes
 
 
 class UploadFile(InternalMessage):
 
-    __slots__ = ("sock", "file", "size", "sentbytes", "offset")
+    __slots__ = ("init", "token", "file", "size", "sentbytes", "offset")
 
-    def __init__(self, sock=None, file=None, size=None, sentbytes=0, offset=None):
-        self.sock = sock
+    def __init__(self, init=None, token=None, file=None, size=None, sentbytes=0, offset=None):
+        self.init = init
+        self.token = token
         self.file = file
         self.size = size
         self.sentbytes = sentbytes
@@ -223,10 +234,11 @@ class DownloadFileError(InternalMessage):
     """ Sent by networking thread to indicate that a file error occurred during
     filetransfer. """
 
-    __slots__ = ("sock", "file", "error")
+    __slots__ = ("user", "token", "file", "error")
 
-    def __init__(self, sock=None, file=None, error=None):
-        self.sock = sock
+    def __init__(self, user=None, token=None, file=None, error=None):
+        self.user = user
+        self.token = token
         self.file = file
         self.error = error
 
@@ -235,21 +247,23 @@ class UploadFileError(DownloadFileError):
     pass
 
 
-class DownloadConnClose(InternalMessage):
+class DownloadConnectionClosed(InternalMessage):
     """ Sent by networking thread to indicate a file transfer connection has been closed """
 
-    __slots__ = ("sock",)
+    __slots__ = ("user", "token")
 
-    def __init__(self, sock=None):
-        self.sock = sock
+    def __init__(self, user=None, token=None):
+        self.user = user
+        self.token = token
 
 
-class UploadConnClose(InternalMessage):
+class UploadConnectionClosed(InternalMessage):
 
-    __slots__ = ("sock", "timed_out")
+    __slots__ = ("user", "token", "timed_out")
 
-    def __init__(self, sock=None, timed_out=None):
-        self.sock = sock
+    def __init__(self, user=None, token=None, timed_out=None):
+        self.user = user
+        self.token = token
         self.timed_out = timed_out
 
 
@@ -2618,20 +2632,20 @@ class FolderContentsRequest(PeerMessage):
     """ Peer code: 36 """
     """ We ask the peer to send us the contents of a single folder. """
 
-    def __init__(self, init=None, directory=None):
+    def __init__(self, init=None, directory=None, token=None):
         self.init = init
         self.dir = directory
-        self.something = None
+        self.token = token
 
     def make_network_message(self):
         msg = bytearray()
-        msg.extend(self.pack_uint32(1))
+        msg.extend(self.pack_uint32(self.token))
         msg.extend(self.pack_string(self.dir, latin1=True))
 
         return msg
 
     def parse_network_message(self, message):
-        pos, self.something = self.unpack_uint32(message)
+        pos, self.token = self.unpack_uint32(message)
         pos, self.dir = self.unpack_string(message, pos)
 
 
@@ -2640,9 +2654,10 @@ class FolderContentsResponse(PeerMessage):
     """ A peer responds with the contents of a particular folder
     (with all subfolders) after we've sent a FolderContentsRequest. """
 
-    def __init__(self, init=None, directory=None, shares=None):
+    def __init__(self, init=None, directory=None, token=None, shares=None):
         self.init = init
         self.dir = directory
+        self.token = token
         self.list = shares
 
     def parse_network_message(self, message):
@@ -2651,43 +2666,41 @@ class FolderContentsResponse(PeerMessage):
 
     def _parse_network_message(self, message):
         shares = {}
-        pos, nfolders = self.unpack_uint32(message)
+        pos, self.token = self.unpack_uint32(message)
+        pos, folder = self.unpack_string(message, pos)
 
-        for _ in range(nfolders):
-            pos, folder = self.unpack_string(message, pos)
+        shares[folder] = {}
 
-            shares[folder] = {}
+        pos, ndir = self.unpack_uint32(message, pos)
 
-            pos, ndir = self.unpack_uint32(message, pos)
+        for _ in range(ndir):
+            pos, directory = self.unpack_string(message, pos)
+            directory = directory.replace('/', '\\')
+            pos, nfiles = self.unpack_uint32(message, pos)
 
-            for _ in range(ndir):
-                pos, directory = self.unpack_string(message, pos)
-                directory = directory.replace('/', '\\')
-                pos, nfiles = self.unpack_uint32(message, pos)
+            shares[folder][directory] = []
 
-                shares[folder][directory] = []
+            for _ in range(nfiles):
+                pos, code = self.unpack_uint8(message, pos)
+                pos, name = self.unpack_string(message, pos)
+                pos, size = self.unpack_uint64(message, pos)
+                pos, ext = self.unpack_string(message, pos)
+                pos, numattr = self.unpack_uint32(message, pos)
 
-                for _ in range(nfiles):
-                    pos, code = self.unpack_uint8(message, pos)
-                    pos, name = self.unpack_string(message, pos)
-                    pos, size = self.unpack_uint64(message, pos)
-                    pos, ext = self.unpack_string(message, pos)
-                    pos, numattr = self.unpack_uint32(message, pos)
+                attrs = {}
 
-                    attrs = {}
+                for _ in range(numattr):
+                    pos, attrnum = self.unpack_uint32(message, pos)
+                    pos, attr = self.unpack_uint32(message, pos)
+                    attrs[str(attrnum)] = attr
 
-                    for _ in range(numattr):
-                        pos, attrnum = self.unpack_uint32(message, pos)
-                        pos, attr = self.unpack_uint32(message, pos)
-                        attrs[str(attrnum)] = attr
-
-                    shares[folder][directory].append((code, name, size, ext, attrs))
+                shares[folder][directory].append((code, name, size, ext, attrs))
 
         self.list = shares
 
     def make_network_message(self):
         msg = bytearray()
-        msg.extend(self.pack_uint32(1))
+        msg.extend(self.pack_uint32(self.token))
         msg.extend(self.pack_string(self.dir))
         msg.extend(self.pack_uint32(1))
         msg.extend(self.pack_string(self.dir))
