@@ -25,6 +25,7 @@ from operator import itemgetter
 from pynicotine import slskmessages
 from pynicotine import utils
 from pynicotine.logfacility import log
+from pynicotine.slskmessages import UserStatus
 from pynicotine.utils import clean_file
 from pynicotine.utils import encode_path
 from pynicotine.utils import get_result_bitrate_length
@@ -68,12 +69,12 @@ class UserBrowse:
         if self.ui_callback:
             self.ui_callback.remove_user(user)
 
-    def show_user(self, user, path=None, local_shares_type=None, indeterminate_progress=False, switch_page=True):
+    def show_user(self, user, path=None, local_shares_type=None, switch_page=True):
 
         self.add_user(user)
 
         if self.ui_callback:
-            self.ui_callback.show_user(user, path, local_shares_type, indeterminate_progress, switch_page)
+            self.ui_callback.show_user(user, path, local_shares_type, switch_page)
 
     def parse_local_shares(self, username, msg):
         """ Parse a local shares list and show it in the UI """
@@ -95,7 +96,7 @@ class UserBrowse:
             thread.daemon = True
             thread.start()
 
-        self.show_user(username, path=path, local_shares_type="normal", indeterminate_progress=True)
+        self.show_user(username, path=path, local_shares_type="normal")
 
     def browse_local_buddy_shares(self, path=None, new_request=False):
         """ Browse your own buddy shares """
@@ -109,7 +110,7 @@ class UserBrowse:
             thread.daemon = True
             thread.start()
 
-        self.show_user(username, path=path, local_shares_type="buddy", indeterminate_progress=True)
+        self.show_user(username, path=path, local_shares_type="buddy")
 
     def browse_user(self, username, path=None, local_shares_type=None, new_request=False, switch_page=True):
         """ Browse a user's shares """
@@ -128,7 +129,7 @@ class UserBrowse:
         user_exists = (username in self.users)
         self.show_user(username, path=path, switch_page=switch_page)
 
-        if not self.core.logged_in:
+        if self.core.user_status == UserStatus.OFFLINE:
             self.show_connection_error(username)
             return
 
@@ -309,9 +310,13 @@ class UserBrowse:
         if self.ui_callback:
             self.ui_callback.show_connection_error(username)
 
-    def message_progress(self, msg):
+    def peer_message_progress(self, msg):
         if self.ui_callback:
-            self.ui_callback.message_progress(msg)
+            self.ui_callback.peer_message_progress(msg)
+
+    def peer_connection_closed(self, msg):
+        if self.ui_callback:
+            self.ui_callback.peer_connection_closed(msg)
 
     def get_user_status(self, msg):
         """ Server code: 7 """
