@@ -1,7 +1,7 @@
 # COPYRIGHT (C) 2020-2022 Nicotine+ Contributors
 # COPYRIGHT (C) 2020 Lene Preuss <lene.preuss@gmail.com>
 # COPYRIGHT (C) 2016-2017 Michael Labouebe <gfarmerfr@free.fr>
-# COPYRIGHT (C) 2007 Daelstorm <daelstorm@gmail.com>
+# COPYRIGHT (C) 2007 daelstorm <daelstorm@gmail.com>
 # COPYRIGHT (C) 2003-2004 Hyriand <hyriand@thegraveyard.org>
 # COPYRIGHT (C) 2001-2003 Alexander Kanavin
 #
@@ -407,10 +407,22 @@ def humanize(number):
     return "{:n}".format(number)
 
 
-def truncate_string_byte(string, byte_limit, encoding='utf-8'):
+def truncate_string_byte(string, byte_limit, encoding='utf-8', ellipsize=False):
     """ Truncates a string to fit inside a byte limit """
 
-    return string.encode(encoding)[:max(byte_limit, 0)].decode(encoding, 'ignore')
+    string_bytes = string.encode(encoding)
+
+    if len(string_bytes) <= byte_limit:
+        # Nothing to do, return original string
+        return string
+
+    if ellipsize:
+        ellipsis = "…".encode(encoding)
+        string_bytes = string_bytes[:max(byte_limit - len(ellipsis), 0)].rstrip() + ellipsis
+    else:
+        string_bytes = string_bytes[:byte_limit]
+
+    return string_bytes.decode(encoding, 'ignore')
 
 
 def unescape(string):
